@@ -1,23 +1,6 @@
 import argparse,re,os
-from os.path import isdir
-from hytest.utils.log import LogLevel
-from .utils.runner import Collector,Runner
 from .product import version
 
-from .product import version
-
-
-
-def printLogo():    
-    print(f'''           
-    *  *  *  *  *  *  *  *  *  *  *  *  *  *  *  *  *  *     
-    *       hytest {version}             www.python3.vip   *
-    *  *  *  *  *  *  *  *  *  *  *  *  *  *  *  *  *  *
-    '''
-    )
-
-
-
 
 def tagExpressionGen(argstr):
     tagRules = []
@@ -69,6 +52,9 @@ def run() :
 
         exit()
 
+    # 同时执行log里面的初始化日志模块，注册signal的代码
+    from hytest.utils.log import LogLevel
+    from .utils.runner import Collector, Runner
 
     LogLevel.level = args.loglevel
     # print('loglevel',LogLevel.level)
@@ -86,7 +72,13 @@ def run() :
     # print(tag_include_expr)
     # print(tag_exclude_expr)
 
-    printLogo()
+
+    print(f'''           
+    *  *  *  *  *  *  *  *  *  *  *  *  *  *  *  *  *  *     
+    *       hytest {version}             www.python3.vip   *
+    *  *  *  *  *  *  *  *  *  *  *  *  *  *  *  *  *  *
+    '''
+    )
 
     Collector.run(
         casedir=args.case_dir,
